@@ -94,6 +94,9 @@ def _files_and_dirs(glob_file_list: List[str]):
 
 
 def _load_kf_model_for_model_framework(model_framework, model_dir, build_args):
+    from common.lib_support import ensure_kfserving_installed
+    ensure_kfserving_installed()
+
     if model_framework == SKLEARN:
         from server.inference_model import SKLearnModel
         kf_model = SKLearnModel(model_dir=model_dir)
@@ -259,7 +262,9 @@ class WrittenModelScaffoldDefinition(AbstractModelScaffoldDefinition):
             data_files: List[str] = None,
             path_to_scaffold: str = None,
             requirements_file: str = None,
+            python_major_minor: str = None,
     ):
+        # attributes
         self.model = model
         if model_files is None:
             model_files = []
@@ -269,6 +274,9 @@ class WrittenModelScaffoldDefinition(AbstractModelScaffoldDefinition):
         self.data_files = data_files
         self.model_type = model_type
         self.requirements_file = requirements_file
+        self.python_major_minor = python_major_minor
+
+        # generated attributes, order matters
         self.scaffold_dir = self._build_scaffold_directory(path_to_scaffold)
         self._write_config()
         self.kf_model = None
@@ -374,4 +382,9 @@ class WrittenModelScaffoldDefinition(AbstractModelScaffoldDefinition):
                 f.write('\n'.join(self.model_framework_requirements.values()))
 
     def serialize_model_to_directory(self, model_directory):
+        """
+        This method will be called on construction of a `WrittenModelScaffoldDefinition` object.
+
+        It should contain all the logic to create the scaffold build context and write the model to the directory
+        """
         raise NotImplementedError()
